@@ -45,7 +45,7 @@ def teardown_function(function):
 def start_watching(path=None, use_full_emitter=False):
     global emitter
     path = p("") if path is None else path
-    emitter = FSEventsEmitter(event_queue, ObservedWatch(path, recursive=True))
+    emitter = FSEventsEmitter(event_queue, ObservedWatch(path, recursive=True), suppress_history=True)
     emitter.start()
 
 
@@ -127,6 +127,23 @@ E       SystemError: <built-in function stop> returned a result with an error se
         observer.unschedule(w)
 
 
+def test_converting_cfstring_to_pyunicode():
+    """See https://github.com/gorakhargosh/watchdog/issues/762
+    """
+
+    tmpdir = p()
+    start_watching(tmpdir)
+
+    dirname = "TéstClass"
+
+    try:
+        mkdir(p(dirname))
+        event, _ = event_queue.get()
+        assert event.src_path.endswith(dirname)
+    finally:
+        emitter.stop()
+
+
 def test_watchdog_recursive():
     """ See https://github.com/gorakhargosh/watchdog/issues/706
     """
